@@ -3,7 +3,7 @@
 #' Accumulated Local Effects Profiles accumulate local changes in Ceteris Paribus Profiles.
 #' Function \code{\link{accumulated_dependence}} calls \code{\link{ceteris_paribus}} and then \code{\link{aggregate_profiles}}.
 #'
-#' Find more detailes in the \href{https://pbiecek.github.io/ema/accumulatedLocalProfiles.html}{Accumulated Local Dependence Chapter}.
+#' Find more detailes in the \href{http://ema.drwhy.ai/accumulatedLocalProfiles.html}{Accumulated Local Dependence Chapter}.
 #'
 #' @param x an explainer created with function \code{DALEX::explain()}, an object of the class \code{ceteris_paribus_explainer}
 #' or a model to be explained.
@@ -14,22 +14,23 @@
 #' Will be passed to \code{\link{calculate_variable_split}}.
 #' If \code{NULL} then all variables from the validation data will be used.
 #' @param N number of observations used for calculation of partial dependence profiles.
-#' By default, 500 observations will be chosen randomly.
+#' By default, \code{500} observations will be chosen randomly.
 #' @param ... other parameters
 #' @param variable_splits named list of splits for variables, in most cases created with \code{\link{calculate_variable_split}}.
 #' If \code{NULL} then it will be calculated based on validation data avaliable in the \code{explainer}.
 #' @param grid_points number of points for profile. Will be passed to\code{\link{calculate_variable_split}}.
 #' @param label name of the model. By default it's extracted from the \code{class} attribute of the model
-#' @param variable_type a character. If "numerical" then only numerical variables will be calculated.
-#' If "categorical" then only categorical variables will be calculated.
+#' @param variable_type a character. If \code{"numerical"} then only numerical variables will be calculated.
+#' If \code{"categorical"} then only categorical variables will be calculated.
 #'
 #' @references ALEPlot: Accumulated Local Effects (ALE) Plots and Partial Dependence (PD) Plots \url{https://cran.r-project.org/package=ALEPlot},
-#' Explanatory Model Analysis. Explore, Explain and Examine Predictive Models. \url{https://pbiecek.github.io/ema}
+#' Explanatory Model Analysis. Explore, Explain, and Examine Predictive Models. \url{http://ema.drwhy.ai/}
 #'
 #' @return an object of the class \code{aggregated_profiles_explainer}
 #'
 #' @examples
 #' library("DALEX")
+#' library("ingredients")
 #'
 #' model_titanic_glm <- glm(survived ~ gender + age + fare,
 #'                          data = titanic_imputed, family = "binomial")
@@ -45,13 +46,14 @@
 #' plot(adp_glm)
 #'
 #' \donttest{
-#' library("randomForest")
+#' library("ranger")
 #'
-#' model_titanic_rf <- randomForest(survived ~.,  data = titanic_imputed)
+#' model_titanic_rf <- ranger(survived ~., data = titanic_imputed, probability = TRUE)
 #'
 #' explain_titanic_rf <- explain(model_titanic_rf,
 #'                               data = titanic_imputed[,-8],
 #'                               y = titanic_imputed[,8],
+#'                               label = "ranger forest",
 #'                               verbose = FALSE)
 #'
 #' adp_rf <- accumulated_dependence(explain_titanic_rf, N = 200, variable_type = "numerical")
@@ -105,7 +107,7 @@ accumulated_dependence.default <- function(x,
                                            grid_points = 101,
                                            ...,
                                            variable_type = "numerical") {
-  if (N < nrow(data)) {
+  if (!is.null(N) && N < nrow(data)) {
     # sample N points
     ndata <- data[sample(1:nrow(data), N),]
   } else {
